==> 0.0.7.tar.gz: android/src/main/java/com/faranegar/camerakit/CameraKitFlutterView.java <==
package com.faranegar.camerakit;

import android.Manifest;
import android.content.pm.PackageManager;
import android.os.Build;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.core.app.ActivityCompat;

import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.platform.PlatformView;

@RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
public class CameraKitFlutterView implements PlatformView, MethodChannel.MethodCallHandler, FlutterMethodListener {


    private static final int REQUEST_CAMERA_PERMISSION = 10001;
    private final MethodChannel channel;
    private final ActivityPluginBinding activityPluginBinding;
    private CameraView cameraView;

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull final MethodChannel.Result result) {
        if (call.method.equals("requestPermission")) {
            if (ActivityCompat.checkSelfPermission(activityPluginBinding.getActivity(), Manifest.permission.CAMERA) != PackageManager.PERMISSION_GRANTED) {
                ActivityCompat.requestPermissions(activityPluginBinding.getActivity(), new String[]{Manifest.permission.CAMERA}, REQUEST_CAMERA_PERMISSION);
                activityPluginBinding.addRequestPermissionsResultListener(new PluginRegistry.RequestPermissionsResultListener() {
                    @Override
                    public boolean onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
                        for (int i :
                                grantResults) {
                            if (i == PackageManager.PERMISSION_DENIED) {
                                result.success(false);
                                return false;
                            }
                        }
                        result.success(true);
                        return false;
                    }
                });
                return;
            } else {
                result.success(true);
            }
        } else if (call.method.equals("initCamera")) {
            boolean hasTakePicture = call.argument("hasTakePicture");
            boolean hasBarcodeReader = call.argument("hasBarcodeReader");
            char flashMode = call.argument("flashMode").toString().charAt(0);
            cameraView.initCamera(hasTakePicture, hasBarcodeReader, flashMode);
        } else if (call.method.equals("resumeCamera")) {
            cameraView.resumeCamera();

        } else if (call.method.equals("pauseCamera")) {
            cameraView.pauseCamera();
        } else if (call.method.equals("takePicture")) {
            char captureFlashMode = call.argument("flashMode").toString().charAt(0);
            cameraView.takePicture(captureFlashMode);
        }else if (call.method.equals("changeFlashMode")) {
            char captureFlashMode = call.argument("flashMode").toString().charAt(0);
            cameraView.changeFlashMode(captureFlashMode);
        } else {
            result.notImplemented();
        }
    }

    public CameraKitFlutterView(ActivityPluginBinding activityPluginBinding, MethodChannel channel, int viewId) {
        this.channel = channel;
        this.activityPluginBinding = activityPluginBinding;
        this.channel.setMethodCallHandler(this);
    }

    @Override
    public View getView() {
        if (cameraView == null) {
            cameraView = new CameraView(activityPluginBinding.getActivity(), this);
        }
        return cameraView.getView();
    }

    @Override
    public void dispose() {
        if(cameraView != null)
            cameraView.dispose();
    }

    @Override
    public void onBarcodeRead(String barcode) {
        channel.invokeMethod("onBarcodeRead", barcode);
    }

    @Override
    public void onTakePicture(final String filePath) {
        activityPluginBinding.getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                channel.invokeMethod("onTakePicture", filePath);
            }
        });

    }
}

==> 0.0.9.tar.gz: android/src/main/java/com/faranegar/camerakit/CameraKitFlutterView.java <==
package com.faranegar.camerakit;

import android.Manifest;
import android.content.pm.PackageManager;
import android.os.Build;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;
import androidx.core.app.ActivityCompat;

import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.platform.PlatformView;

@RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
public class CameraKitFlutterView implements PlatformView, MethodChannel.MethodCallHandler, FlutterMethodListener {


    private static final int REQUEST_CAMERA_PERMISSION = 10001;
    private final MethodChannel channel;
    private final ActivityPluginBinding activityPluginBinding;
    private CameraView cameraView;

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull final MethodChannel.Result result) {
        if (call.method.equals("requestPermission")) {
            if (ActivityCompat.checkSelfPermission(activityPluginBinding.getActivity(), Manifest.permission.CAMERA) != PackageManager.PERMISSION_GRANTED) {
                ActivityCompat.requestPermissions(activityPluginBinding.getActivity(), new String[]{Manifest.permission.CAMERA}, REQUEST_CAMERA_PERMISSION);
                activityPluginBinding.addRequestPermissionsResultListener(new PluginRegistry.RequestPermissionsResultListener() {
                    @Override
                    public boolean onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
                        for (int i :
                                grantResults) {
                            if (i == PackageManager.PERMISSION_DENIED) {
                                result.success(false);
                                return false;
                            }
                        }
                        result.success(true);
                        return false;
                    }
                });
                return;
            } else {
                result.success(true);
            }
        } else if (call.method.equals("initCamera")) {
            boolean hasTakePicture = call.argument("hasTakePicture");
            boolean hasBarcodeReader = call.argument("hasBarcodeReader");
            char flashMode = call.argument("flashMode").toString().charAt(0);
            cameraView.initCamera(hasTakePicture, hasBarcodeReader, flashMode);
        } else if (call.method.equals("resumeCamera")) {
            cameraView.resumeCamera();

        } else if (call.method.equals("pauseCamera")) {
            cameraView.pauseCamera();
        } else if (call.method.equals("takePicture")) {
            char captureFlashMode = call.argument("flashMode").toString().charAt(0);
            cameraView.takePicture(captureFlashMode);
        }else if (call.method.equals("changeFlashMode")) {
            char captureFlashMode = call.argument("flashMode").toString().charAt(0);
            cameraView.changeFlashMode(captureFlashMode);
        } else {
            result.notImplemented();
        }
    }

    public CameraKitFlutterView(ActivityPluginBinding activityPluginBinding, MethodChannel channel, int viewId) {
        this.channel = channel;
        this.activityPluginBinding = activityPluginBinding;
        this.channel.setMethodCallHandler(this);
    }

    @Override
    public View getView() {
        if (cameraView == null) {
            cameraView = new CameraView(activityPluginBinding.getActivity(), this);
        }
        return cameraView.getView();
    }

    @Override
    public void dispose() {
        if(cameraView != null) {
            cameraView = null;
            cameraView.dispose();
        }
    }

    @Override
    public void onBarcodeRead(String barcode) {
        channel.invokeMethod("onBarcodeRead", barcode);
    }

    @Override
    public void onTakePicture(final String filePath) {
        activityPluginBinding.getActivity().runOnUiThread(new Runnable() {
            @Override
            public void run() {
                channel.invokeMethod("onTakePicture", filePath);
            }
        });

    }
}
